/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include <QObject>
#include <QProcess>

#define SYSTEM_DIR_PATH "/"
#define CACHE_DIR_PATH "/home"
#define OFFLINE_COPY_OUP_PATH "oup/"
#define OFFLINE_COPY_SQUASHFS_PATH "/.cache/deepin-offline-update/"
#define OFFLINE_COPY_AR_PATH "/.cache/deepin-offline-update-ar/"
#define OFFLINE_ARX_INFO "info.json"
#define OFFLINE_ARX_BINARY "oup-format"
#define OFFLINE_ARX_REPO "repo.sfs"
#define OFFLINE_ARX_HOOKS "hooks.sfs"
#define OFFLINE_ARX_INFO_SIGN "info.json_sign"
#define OFFLINE_ARX_BINARY_SIGN "oup-format_sign"
#define OFFLINE_ARX_REPO_SIGN "repo.sfs_sign"
#define OFFLINE_DIR_REPO "repo"
#define OFFLINE_DIR_HOOKS "hooks"
#define SYSTEM_SOURCE_UPDATE_LIST "/etc/deepin-offline-update/update.list"

#define ARCH_AMD "x86_64" // AMD平台
#define ARCH_ARM "aarch64" // ARM平台
#define ARCH_MIPS "mips64" // MIPS平台
#define ARCH_SW "sw_64" // SW平台
#define ARCH_LOONGARCH "loongarch64" // LOONGARCH平台

#define CRP_ARCH_I386 "i386" // i386平台
#define CRP_ARCH_AMD "amd64" // AMD平台
#define CRP_ARCH_ARM "arm64" // ARM平台
#define CRP_ARCH_MIPS "mips64el" // MIPS平台
#define CRP_ARCH_SW "sw_64" // SW平台
#define CRP_ARCH_LOONGARCH "loongarch64" // LOONGARCH平台

class OfflineCheck : public QObject
{
    Q_OBJECT
public:
    explicit OfflineCheck(QObject *parent = nullptr);
    ~OfflineCheck();

    // 开始进行离线包检测
    void startOfflineFileCheck(const QString &homepath, const QString &filepath);
    int getUpgradeType() { return m_upgradeType; }
    QString getPatchUpgradeSerial() { return m_patchUpgradeSerial; }
    int getDistUpgradeSum() { return m_distUpgradeSum; }

    // 执行升级与检测
    int execSystemUpgrade();
    int getUpgradeListSum();

    // 执行安装成功后hook脚本
    void execHookPost(const QString &homepath);

private:
    bool checkOfflineFile(const QString &filepath);
    bool checkOfflineFileDirComplete(const QString &homepath, const QString &filepath);
    void checkOfflineUpgradeType(const QString &homepath);
    bool checkSystemVersion();
    bool checkOfflineFileArch();
    bool checkSystemBackupSpace();
    bool checkUpgradeSum(const QString &homepath);
    bool checkHookPre(const QString &homepath);

    bool checkArOfflineFileDirComplete(const QString &homepath, const QString &filepath);
    void checkArOfflineUpgradeType(const QString &homepath);
    bool checkArSystemVersion();
    bool checkArOfflineFileArch();
    bool checkArSystemBackupSpace();
    bool checkArUpgradeSum(const QString &homepath);

    QString getHomeFreeSize();

public Q_SLOTS:
    void onReadData();

Q_SIGNALS:
    void sendOfflineFileCheckResult(int itemType, bool result);
    void sendExecDistUpgradeInfo(QString info);
    void sendOfflineUpgradeLog(QString log);

private:
    int m_upgradeType = 0;
    QString m_patchUpgradeSerial;
    QString m_offlineType;
    QString m_offlineArchs;
    int m_distUpgradeSum = 0;

    QProcess m_upgradeProcess;

    bool m_isSquashfs;
};
