/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include "daemon_adaptor.h"

#include <QObject>
#include <polkit-qt5-1/PolkitQt1/Authority>

const QString service = "com.deepin.offline.update.daemon";
const QString path = "/com/deepin/offline/update/daemon";

using namespace PolkitQt1;

class QDBusContext;
class DBusInvokerInterface;
class OfflineCheck;
class WriteDBusData : public QObject
    , protected QDBusContext
{
    Q_OBJECT
public:
    explicit WriteDBusData(QObject *parent = nullptr);
    ~WriteDBusData();

private:
    // 校验调用者
    bool isValidInvoker();

public Q_SLOTS:
    void StartApp();
    void ExitApp();

    void StartOfflineFileCheck(QString homepath, QString filepath);
    void acceptOfflineFileCheckResult(int itemType, bool result);
    void acceptExecDistUpgradeInfo(QString info);
    void acceptOfflineUpgradeLog(QString log);
    int GetUpgradeType();
    QString GetPatchUpgradeSerial();
    int GetDistUpgradeSum();

    bool IsAllowBackupSystem();
    void BackupSystem();
    void acceptBackupSystemProgress(QString kind, bool success, QString errMsg);

    void StartUpgradeSystem();
    void StartExecHookPost();

Q_SIGNALS:
    void NotifyOfflineFileCheckResult(int itemType, bool result);
    void NotifyOfflineUpgradeProgress(int progress, int code);
    void NotifyExecDistUpgradeInfo(QString info);
    void NotifyOfflineUpgradeLog(QString info);

private:
    DaemonAdaptor *m_adaptor;
    DBusInvokerInterface *m_ABRecoveryDBusInter; // 备份还原dbus类
    OfflineCheck *m_offlineCheck;

    QString m_homepath;
};
