/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "window/mainwindow.h"
#include "defenderdbusservice.h"

#include <QObject>
#include <QDBusConnection>
#include <QDBusInterface>
#include <QDebug>

#include <DApplication>
#include <DWidgetUtil>
#include <DApplicationSettings>
#include <DLog>

DWIDGET_USE_NAMESPACE
DCORE_USE_NAMESPACE

//转换路径
QUrl UrlInfo(QString path)
{
    QUrl url;
    if (QFile::exists(path)) {
        url = QUrl::fromLocalFile(QDir::current().absoluteFilePath(path));
        return url;
    }

    const auto match = QRegularExpression(QStringLiteral(":(\\d+)(?::(\\d+))?:?$")).match(path);

    if (match.isValid()) {
        path.chop(match.capturedLength());
    }

    url = QUrl::fromUserInput(path, QDir::currentPath(), QUrl::AssumeLocalFile);
    if (!url.isValid()) {
        url = QUrl::fromLocalFile(QDir::current().absoluteFilePath(path));
    }
    return url;
}

int main(int argc, char *argv[])
{
    DApplication a(argc, argv);
    a.setAttribute(Qt::AA_UseHighDpiPixmaps); // 高清图
    a.setOrganizationName("deepin");
    a.setApplicationName("deepin-offline-update-tool");
    a.setApplicationVersion(DApplication::buildVersion((QMAKE_VERSION))); //pro 文件中的版本
    a.loadTranslator();
    a.setApplicationDisplayName("离线升级工具");
    a.setStyle("chameleon");
    a.setWindowIcon(QIcon::fromTheme("upgrade-tool"));
    a.setProductIcon(QIcon::fromTheme("upgrade-tool"));
    a.setApplicationDescription(QApplication::translate("main", "system upgrade tool deepin system upgrade tool in Linux"));
    a.setQuitOnLastWindowClosed(false);

    DLogManager::registerConsoleAppender();
    DLogManager::registerFileAppender();

    MainWindow w;
    Dtk::Widget::moveToCenter(&w);

    //regist dbus service
    DefenderDBusService dbus(&w);

    // 程序启动参数判断
    QStringList arguments = QCoreApplication::arguments();
    bool offlineStatus = false;
    bool isoStatus = false;
    for (QString path : arguments) {
        path = UrlInfo(path).toLocalFile();
        if (path.contains(".oup")) {
            offlineStatus = true;
            w.setOfflineUpdateFile(path);
        } else if (path.contains(".iso")) {
            isoStatus = true;
            w.setISOUpdateFile(path);
        }
    }
    if (!offlineStatus && !isoStatus && arguments.count() > 2) {
        w.showErrorFileType();
    }

    w.show();
    return a.exec();
}
