/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "window/interface/frameproxyinterface.h"
#include "window/interface/moduleinterface.h"

#include <QHBoxLayout>
#include <QStandardItemModel>
#include <QSystemTrayIcon>
#include <QGSettings>

#include <DMainWindow>
#include <DDialog>

DWIDGET_BEGIN_NAMESPACE
class DBackgroundGroup;
DWIDGET_END_NAMESPACE

DWIDGET_USE_NAMESPACE
class MultiSelectListView;
class OfflineUpdateModule;
class MainWindow : public DTK_WIDGET_NAMESPACE::DMainWindow
    , public FrameProxyInterface
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = nullptr);
    ~MainWindow() override;

    // 模板函数,供各模块调用
    void popWidget(ModuleInterface *const inter) override; //弹栈
    void popAndDelWidget(ModuleInterface *const inter) override;
    void pushWidget(ModuleInterface *const inter, QWidget *const w) override; //压栈
    void setModuleVisible(ModuleInterface *const inter, const bool visible) override; //模块可视化
    void setCurrentModule(int iModuleIdx, int iPageIdx = 0) override; //设置当前模块
    ModuleInterface *getCurrentModule() override;
    int getModuleIndex(const QString &name) override; //获得模块下标

    void initAllModule();
    void showModulePage(const QString &module, const QString &page);
    int getModuleCount();
    int getPageIndex(QString pageName);

    void setOfflineUpdateFile(QString filepath);
    void setISOUpdateFile(QString filepath);
    void showErrorFileType();

private:
    // 初始化
    void initUI();
    void initData();
    void initTray();
    void modulePreInitialize();

    void popAllWidgets(int place = 0);
    void popWidget();
    void pushNormalWidget(ModuleInterface *const inter, QWidget *const w);

private Q_SLOTS:
    void closeWindow();

    void onFirstItemClick(const QModelIndex &index);
    void onTrayActivated(QSystemTrayIcon::ActivationReason state);

protected:
    void closeEvent(QCloseEvent *event) override;

private:
    QHBoxLayout *m_contentLayout;
    QHBoxLayout *m_rightContentLayout;
    MultiSelectListView *m_navView;
    DTK_WIDGET_NAMESPACE::DBackgroundGroup *m_rightView;
    QStandardItemModel *m_navModel;
    QStack<QPair<ModuleInterface *, QWidget *>> m_contentStack;
    QList<QPair<ModuleInterface *, QString>> m_modules;

    OfflineUpdateModule *m_offLineUpdateModule; // 离线更新模块

    QSystemTrayIcon *m_pSystemTray; // 系统托盘图标
    QMenu *m_trayMenu; // 托盘目录
    DDialog *m_trayDialag;

    QGSettings *m_settings;
    bool m_navShowStatus;
};

#endif // MAINWINDOW_H
