/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "confirmdialog.h"
#include "window/modules/common/compixmap.h"

#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QScrollBar>
#include <QPushButton>

#include <DLabel>
#include <DScrollArea>
#include <DFontSizeManager>
#include <DCheckBox>

const int dialogWidth = 450;
const int dialogHeight = 280;

ConfirmDialog::ConfirmDialog(bool status, QWidget *parent)
    : DDialog(parent)
    , m_status(status)
    , m_checkBox(nullptr)
    , m_cancelBtn(nullptr)
    , m_okBtn(nullptr)
{
    setIcon(QIcon::fromTheme(DIALOG_TIP_YELLOW));
    this->setFixedSize(dialogWidth, dialogHeight);

    this->setContentsMargins(0, 0, 0, 0);
    DWidget *widget = new DWidget(this);
    addContent(widget);

    // 主布局
    QVBoxLayout *layout = new QVBoxLayout(widget);
    layout->setContentsMargins(10, 0, 10, 10);
    layout->setSpacing(0);
    widget->setLayout(layout);

    // 文案
    DLabel *label = new DLabel();
    if (m_status) {
        label->setText(tr("During the upgrade process you will not be able to operate your computer. "
                          "After the upgrade is complete, the computer will automatically restart."
                          " Please make sure you have saved your important files before checking the options below to continue the upgrade!"));
    } else {
        label->setText(tr("Your system does not support backup and restore. "
                          "If the system fails to start up after upgrade, it cannot be recovered. Confirm to continue the upgrade?"));
    }
    label->setAlignment(Qt::AlignCenter);
    label->setWordWrap(true);
    DFontSizeManager::instance()->bind(label, DFontSizeManager::T6);
    layout->addWidget(label, 0, Qt::AlignCenter);

    layout->addSpacing(10);
    // 勾选框
    m_checkBox = new DCheckBox(tr("I acknowledge and confirm to continue the upgrade"), this);
    DFontSizeManager::instance()->bind(m_checkBox, DFontSizeManager::T6);
    layout->addWidget(m_checkBox, 0, Qt::AlignCenter);
    connect(m_checkBox, &QCheckBox::stateChanged, this, &ConfirmDialog::checkBoxChange);

    layout->addSpacing(10);
    // 按钮
    QHBoxLayout *bottomLayout = new QHBoxLayout(this);
    bottomLayout->setContentsMargins(0, 0, 0, 0);
    bottomLayout->setSpacing(10);
    layout->addLayout(bottomLayout);

    // 取消按钮
    m_cancelBtn = new QPushButton(this);
    DFontSizeManager::instance()->bind(m_cancelBtn, DFontSizeManager::T6);
    m_cancelBtn->setText(tr("Postpone Upgrade"));
    bottomLayout->addWidget(m_cancelBtn);
    connect(m_cancelBtn, &QCheckBox::clicked, this, [=] {
        this->reject();
    });

    // 分割线
    QFrame *line = new QFrame(this);
    line->setFrameShape(QFrame::VLine);
    line->setFrameShadow(QFrame::Sunken);
    bottomLayout->addWidget(line);

    // 确认按钮
    m_okBtn = new DWarningButton(this);
    m_okBtn->setText(tr("Continue Upgrade"));
    m_okBtn->setAttribute(Qt::WA_NoMousePropagation);
    bottomLayout->addWidget(m_okBtn);
    m_okBtn->setEnabled(false);
    connect(m_okBtn, &QCheckBox::clicked, this, [=] {
        Q_EMIT sendStartUpgrade();
        this->accept();
    });
}

ConfirmDialog::~ConfirmDialog()
{
}

// 选择框的改变
void ConfirmDialog::checkBoxChange(int status)
{
    m_okBtn->setEnabled(status);
}
