/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "licensedialog.h"
#include "window/modules/common/compixmap.h"

#include <QVBoxLayout>
#include <QScrollBar>

#include <DLabel>
#include <DScrollArea>
#include <DFontSizeManager>

const int dialogWidth = 513;
const int dialogHeight = 455;
const int scrollAreaWidth = 433;

LicenseDialog::LicenseDialog(const QString &title, QWidget *parent)
    : DDialog(parent)
{
    this->setFixedSize(dialogWidth, dialogHeight);

    DWidget *MainWidget = new DWidget(this);
    MainWidget->setFixedSize(dialogWidth, dialogHeight);

    DLabel *titleLabel = new DLabel(title);
    titleLabel->setWordWrap(true);
    DFontSizeManager::instance()->bind(titleLabel, DFontSizeManager::T6);
    titleLabel->setAlignment(Qt::AlignCenter);
    QHBoxLayout *titleLayout = new QHBoxLayout;
    titleLayout->setMargin(0);
    titleLayout->setSpacing(0);
    titleLayout->addStretch();
    titleLayout->addWidget(titleLabel);
    titleLayout->addStretch();

    // widget
    QWidget *widget = new QWidget(this);
    QVBoxLayout *widgetLayout = new QVBoxLayout(widget);
    widgetLayout->setContentsMargins(40, 0, 40, 40);
    widgetLayout->setSpacing(0);
    widget->setLayout(widgetLayout);

    //  文案 -警告
    DLabel *warningLabel = new DLabel(tr("Note: Do not forcibly shut down or cut power during system restore, otherwise it will damage the system."));
    warningLabel->setWordWrap(true);
    QPalette pal = warningLabel->palette();
    pal.setColor(QPalette::WindowText, Qt::red);
    warningLabel->setPalette(pal);
    DFontSizeManager::instance()->bind(warningLabel, DFontSizeManager::T8);
    warningLabel->setFixedWidth(scrollAreaWidth);
    widgetLayout->addWidget(warningLabel);

    widgetLayout->setSpacing(10);
    //  文案1
    DLabel *licenseLabel_1 = new DLabel(tr("1.If the system fails to start up properly, "
                                           "you can try to restart the device and quickly press the arrow keys on the keyboard when entering the GRUB "
                                           "interface shown in the picture below. The system will stay in the GRUB interface."));
    licenseLabel_1->setWordWrap(true);
    DFontSizeManager::instance()->bind(licenseLabel_1, DFontSizeManager::T8);
    licenseLabel_1->setFixedWidth(scrollAreaWidth);
    widgetLayout->addWidget(licenseLabel_1);

    widgetLayout->setSpacing(10);
    // 图片
    QLabel *logoPic = new QLabel;
    logoPic->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
    logoPic->setAlignment(Qt::AlignHCenter);
    logoPic->setPixmap(QIcon::fromTheme(":/icons/deepin/builtin/icons/systemrecover.jpg").pixmap(scrollAreaWidth, 232));
    widgetLayout->addWidget(logoPic, 0, Qt::AlignCenter);

    widgetLayout->setSpacing(10);
    //  文案2
    DLabel *licenseLabel_2 = new DLabel(tr("2.Use the ↑↓ arrow keys on the keyboard to move the selection bar to the \"回退到UOS Desktop 20 Professional（xxxx）\" option,"
                                           " and press Enter to initiate the restore process."));
    licenseLabel_2->setWordWrap(true);
    DFontSizeManager::instance()->bind(licenseLabel_2, DFontSizeManager::T8);
    licenseLabel_2->setFixedWidth(scrollAreaWidth);
    widgetLayout->addWidget(licenseLabel_2);

    //  设置滚动区域
    DScrollArea *scrollArea = new DScrollArea;
    scrollArea->viewport()->setStyleSheet("background-color:transparent;");
    scrollArea->setWidget(widget);
    scrollArea->setAlignment(Qt::AlignmentFlag::AlignCenter);
    scrollArea->setWidgetResizable(true);
    scrollArea->setLineWidth(0);
    scrollArea->setFrameStyle(QFrame::NoFrame);
    scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
    scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    scrollArea->setContextMenuPolicy(Qt::NoContextMenu);
    scrollArea->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
    scrollArea->verticalScrollBar()->setContextMenuPolicy(Qt::NoContextMenu);
    scrollArea->horizontalScrollBar()->setContextMenuPolicy(Qt::NoContextMenu);

    QVBoxLayout *vboxLayout = new QVBoxLayout;
    vboxLayout->setMargin(0);
    vboxLayout->setSpacing(0);
    vboxLayout->addSpacing(50);
    vboxLayout->addLayout(titleLayout);
    vboxLayout->addSpacing(20);
    vboxLayout->addWidget(scrollArea);
    vboxLayout->addStretch();
    vboxLayout->setAlignment(Qt::AlignmentFlag::AlignCenter);

    DBlurEffectWidget *blurEffectLicenseWidgets = new DBlurEffectWidget;
    blurEffectLicenseWidgets->setLayout(vboxLayout);
    blurEffectLicenseWidgets->resize(dialogWidth, dialogHeight);
    blurEffectLicenseWidgets->setRadius(200);
    blurEffectLicenseWidgets->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
    blurEffectLicenseWidgets->lower();

    QHBoxLayout *layout = new QHBoxLayout;
    layout->setMargin(0);
    layout->setSpacing(0);
    layout->addWidget(blurEffectLicenseWidgets);

    MainWidget->setLayout(layout);
}

LicenseDialog::~LicenseDialog()
{
}
