/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include "offlineupdatedelegate.h"
#include "widgets/defendertableheaderview.h"

#include <DWidget>
#include <DFrame>
#include <DSuggestButton>
#include <DLabel>
#include <DTipLabel>
#include <DSpinner>
#include <DTableView>
#include <DCommandLinkButton>

#include <QStandardItemModel>

class QStandardItemModel;
class OfflineUpdateModel;
class OfflineUpgradeDialog;

struct CheckResultInfo {
    QString name;
    QString resultinfo;
    int resultvalue;
};

DWIDGET_USE_NAMESPACE
class OfflineCheckResultWidget : public QWidget
{
    Q_OBJECT

public:
    explicit OfflineCheckResultWidget(OfflineUpdateModel *model, int itemType, bool result, DWidget *parent = nullptr);
    ~OfflineCheckResultWidget() override;

private:
    // 初始化
    void initUI();
    QWidget *loadCheckErrorWidget();
    QWidget *loadCheckResultWidget();
    QWidget *loadOfflineUpdateTable();

    // 设置结果页显示空间
    void setCheckResultWidget(int itemType, bool result);

private Q_SLOTS:
    // 选择框的改变
    void checkBoxChange(int status);
    // 开始升级
    void startCVEUpgrade();
    void acceptOfflineUpgradeProgress(int progress, int code);
    void acceptExecDistUpgradeInfo(QString info);
    void backSystemCheckBoxChange(int status);

protected:
    bool eventFilter(QObject *obj, QEvent *event) override;

private:
    OfflineUpdateModel *m_model;
    int m_itemType;
    bool m_result;

    QWidget *m_errorContent;
    DLabel *m_errorLabel;
    QWidget *m_resultContent;

    DTableView *m_tableView;
    QStandardItemModel *m_tableModel;
    DefenderTableHeaderView *m_headerDelegate; // 表头代理类
    OfflineUpdateDelegate *m_offlineUpdateDelegate;

    QCheckBox *m_checkBox;
    DCommandLinkButton *m_recoverSystemBtn;

    QCheckBox *m_backSystemCheckBox;

    DLabel *m_logLabel;
    DTipLabel *m_logPathLabel;

    DSuggestButton *m_upgradeBtn;

    OfflineUpgradeDialog *m_offlineUpgradeDialog;
};
