/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "offlineupdatecheckingwidget.h"
#include "offlineupdatemodel.h"
#include "window/modules/common/compixmap.h"

#include <DFontSizeManager>

#include <QVBoxLayout>
#include <QPalette>
#include <QColor>
#include <QFileDialog>

OfflineUpdateCheckingWidget::OfflineUpdateCheckingWidget(OfflineUpdateModel *model, DWidget *parent)
    : DWidget(parent)
    , m_model(model)
    , m_waitSpinner(nullptr)
    , m_waitingLabel(nullptr)
{
    // 初始化
    initUI();
    initData();
}

OfflineUpdateCheckingWidget::~OfflineUpdateCheckingWidget()
{
    m_waitSpinner->stop();
    if (m_waitSpinner) {
        m_waitSpinner->deleteLater();
        m_waitSpinner = nullptr;
    }
}

// 初始化界面
void OfflineUpdateCheckingWidget::initUI()
{
    // 主布局
    QVBoxLayout *mainLayout = new QVBoxLayout(this);
    mainLayout->setContentsMargins(0, 0, 0, 0);
    mainLayout->setSpacing(10);
    this->setLayout(mainLayout);

    mainLayout->addStretch();
    // 等待控件
    m_waitSpinner = new DSpinner(this);
    m_waitSpinner->setFixedSize(100, 100);
    mainLayout->addWidget(m_waitSpinner, 0, Qt::AlignCenter);

    // 等待文案
    m_waitingLabel = new DLabel(this);
    m_waitingLabel->setText(tr("Upgrade package detection in progress, please wait"));
    DFontSizeManager::instance()->bind(m_waitingLabel, DFontSizeManager::T6);
    mainLayout->addWidget(m_waitingLabel, 0, Qt::AlignCenter);

    mainLayout->addStretch();
}

void OfflineUpdateCheckingWidget::initData()
{
    m_waitSpinner->start();
}

// 停止等待
void OfflineUpdateCheckingWidget::stopWaiting()
{
    if (m_waitSpinner) {
        m_waitSpinner->stop();
    }
}
