/*
 * Copyright (C) 2023 ~ 2023 Deepin Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "offlineupdatedelegate.h"
#include <DApplicationHelper>
#include "window/modules/common/compixmap.h"

#include <QPainter>
#include <QMouseEvent>
#include <QToolTip>
#include <QApplication>

#define ICON_SIZE 16

OfflineUpdateDelegate::OfflineUpdateDelegate(QObject *parent)
    : QStyledItemDelegate(parent)

{
}

// 绘制
void OfflineUpdateDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
{
    // 设置交替色
    if (index.row() % 2 == 1) {
        DPalette pal(DApplicationHelper::instance()->palette(option.widget));
        QPainterPath path;

        if (index.column() == 0) {
            path.setFillRule(Qt::WindingFill);
            path.addRoundedRect(option.rect, 10, 10);
            QRect temp_rect(option.rect.left() + 10, option.rect.top(), option.rect.width() - 10, option.rect.height());
            path.addRect(temp_rect);
            painter->fillPath(path, pal.brush(DPalette::ItemBackground));
        } else {
            path.setFillRule(Qt::WindingFill);
            path.addRoundedRect(option.rect, 10, 10);
            QRect temp_rect(option.rect.left(), option.rect.top(), option.rect.width() / 2, option.rect.height());
            path.addRect(temp_rect);
            painter->fillPath(path, pal.brush(DPalette::ItemBackground));
        }
    }

    // 绘画坐标
    QRect rect = option.rect;
    int height = rect.height();
    int x = rect.x() + 10;
    int y = rect.y() + height / 2 + height / 8;

    // 0列
    if (TABLE_COLUMN_CHECKITEM == index.column()) {
        painter->save();
        QString sName = index.model()->data(index.model()->index(index.row(), TABLE_COLUMN_CHECKITEM), Qt::DisplayRole).toString();

        int textWidth = rect.width() - 18;
        QString sElideName = painter->fontMetrics().elidedText(sName, Qt::ElideMiddle, textWidth, Qt::TextShowMnemonic);
        painter->drawText(x + 8, y, sElideName);
        painter->restore();
    }
    // 1列
    if (TABLE_COLUMN_CHECKRESULT == index.column()) {
        painter->save();
        QString sResultInfo = index.model()->data(index.model()->index(index.row(), TABLE_COLUMN_CHECKRESULT), Qt::DisplayRole).toString();
        int nResultValue = index.model()->data(index.model()->index(index.row(), TABLE_COLUMN_CHECKVALUE), Qt::DisplayRole).toInt();

        QPen pen;
        if (CHECK_RESULT_PASS == nResultValue) {
            pen.setColor(Qt::green);
        } else if (CHECK_RESULT_NOPASS == nResultValue) {
            pen.setColor(Qt::red);
        }
        painter->setPen(pen);

        int textWidth = rect.width() - 10;
        QString sElidePath = painter->fontMetrics().elidedText(sResultInfo, Qt::ElideMiddle, textWidth, Qt::TextShowMnemonic);
        painter->drawText(x, y, sElidePath);
        painter->restore();
    }
}
