/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include <QObject>

class DBusInvokerInterface;
class OfflineUpdateModel : public QObject
{
    Q_OBJECT
public:
    explicit OfflineUpdateModel(QObject *parent = nullptr);
    ~OfflineUpdateModel();

    // 设置检测文件路径
    void setCheckFilePath(const QString &filepath);
    // 开始离线包检测
    void startOfflineFileChecking(const QString &filepath);
    int getUpgradeType();
    QString getPatchUpgradeSerial();
    int getDistUpgradeSum();

    // ab系统备份是否允许进行备份
    bool getABSystemBackupStatus();

    // 获取桌面壁纸
    QString getDesktopImage();

    // 开始升级
    void startOfflineUpgrade(bool canBackup);
    // 重启
    void systemReboot();

private:
    // 初始化数据
    void initData();

public Q_SLOTS:
    void acceptOfflineFileCheckResult(int itemType, bool result);
    void acceptOfflineUpgradeProgress(int progress, int code);
    void acceptExecDistUpgradeInfo(QString info);
    void acceptOfflineUpgradeLog(QString log);

Q_SIGNALS:
    void notifyCheckFilePath(QString filepath);
    void notifyOfflineCheckResult(int itemType, bool result);
    void notifyOfflineUpgradeProgress(int progress, int code);
    void notifyExecDistUpgradeInfo(QString info);
    void notifyToolExit();

private:
    DBusInvokerInterface *m_systemUpgradeDBusInter; // 原子更新dbus类
    DBusInvokerInterface *m_wmDBusInter; // 桌面壁纸获取dbus类
    DBusInvokerInterface *m_rebootDBusInter; // 系统重启dbus类
};
