/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "offlineupdatemodule.h"
#include "offlineupdatewidget.h"
#include "offlineupdatecheckingwidget.h"
#include "offlinecheckresultwidget.h"
#include "offlineupdatemodel.h"

#include <QModelIndex>
#include <QStandardItemModel>

OfflineUpdateModule::OfflineUpdateModule(FrameProxyInterface *frame, QObject *parent)
    : QObject(parent)
    , ModuleInterface(frame)
    , m_offlineUpdateWidget(nullptr)
    , m_offlineUpdateCheckingWidget(nullptr)
    , m_offlineCheckResultWidget(nullptr)
    , m_offlineUpdateModel(nullptr)
{
}

OfflineUpdateModule::~OfflineUpdateModule()
{
    deactive();
}

void OfflineUpdateModule::initialize()
{
}

void OfflineUpdateModule::preInitialize()
{
}

const QString OfflineUpdateModule::name() const
{
    return "offlineupdate";
}

void OfflineUpdateModule::active(int index)
{
    Q_UNUSED(index)

    if (!m_offlineUpdateModel) {
        m_offlineUpdateModel = new OfflineUpdateModel(this);
        connect(m_offlineUpdateModel, &OfflineUpdateModel::notifyCheckFilePath, this, &OfflineUpdateModule::acceptCheckFilePath);
        connect(m_offlineUpdateModel, &OfflineUpdateModel::notifyOfflineCheckResult, this, &OfflineUpdateModule::acceptOfflineCheckResult);
        connect(m_offlineUpdateModel, &OfflineUpdateModel::notifyToolExit, this, &OfflineUpdateModule::sendToolExit);
    }

    m_offlineUpdateWidget = new OfflineUpdateWidget(m_offlineUpdateModel);
    m_offlineUpdateWidget->show();
    m_frameProxy->pushWidget(this, m_offlineUpdateWidget);
}

void OfflineUpdateModule::deactive()
{
}

// 双击文件-主动触发离线文件导入按钮
void OfflineUpdateModule::setOfflineUpdateFile(QString filepath)
{
    if (nullptr != m_offlineUpdateWidget) {
        m_offlineUpdateWidget->setOfflineUpdateFile(filepath);
    }
}

// 加载正在检测界面
void OfflineUpdateModule::acceptCheckFilePath(QString filepath)
{
    m_offlineUpdateWidget->deleteLater();
    if (!m_offlineUpdateCheckingWidget) {
        m_offlineUpdateCheckingWidget = new OfflineUpdateCheckingWidget(m_offlineUpdateModel);
        m_frameProxy->pushWidget(this, m_offlineUpdateCheckingWidget);

        // 开始进行离线包检测
        m_offlineUpdateModel->startOfflineFileChecking(filepath);
    }
}

// 加载正在检测结果界面
void OfflineUpdateModule::acceptOfflineCheckResult(int itemType, bool result)
{
    m_offlineUpdateCheckingWidget->stopWaiting();
    m_offlineUpdateCheckingWidget->deleteLater();
    if (!m_offlineCheckResultWidget) {
        m_offlineCheckResultWidget = new OfflineCheckResultWidget(m_offlineUpdateModel, itemType, result);
        m_frameProxy->pushWidget(this, m_offlineCheckResultWidget);
    }
}
