/*
 * Copyright (C) 2023 ~ 2024 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caimengci <caimengci@uniontech.com>
 *
 * Maintainer: caimengci <caimengci@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "offlineupdatewidget.h"
#include "offlineupdatemodel.h"

#include <QVBoxLayout>
#include <QPalette>
#include <QColor>
#include <QFileDialog>

OfflineUpdateWidget::OfflineUpdateWidget(OfflineUpdateModel *model, DWidget *parent)
    : DWidget(parent)
    , m_model(model)
    , m_importButton(nullptr)
{
    // 初始化UI
    initUI();
}

OfflineUpdateWidget::~OfflineUpdateWidget()
{
}

// 初始化界面
void OfflineUpdateWidget::initUI()
{
    // 主布局
    QVBoxLayout *mainLayout = new QVBoxLayout(this);
    mainLayout->setContentsMargins(0, 0, 0, 0);
    mainLayout->setSpacing(10);

    // 导入按钮
    m_importButton = new DSuggestButton(this);
    m_importButton->setFixedWidth(200);
    m_importButton->setText(tr("Import offline file (.oup)"));
    mainLayout->addWidget(m_importButton, 0, Qt::AlignHCenter);
    connect(m_importButton, &DPushButton::clicked, this, &OfflineUpdateWidget::acceptImportFiles);
}

void OfflineUpdateWidget::acceptImportFiles()
{
    QString fileName = QFileDialog::getOpenFileName(this, tr("Import offline file (.oup)"), "", "oup Files (*.oup)");
    setOfflineUpdateFile(fileName);
}

void OfflineUpdateWidget::setOfflineUpdateFile(QString filepath)
{
    if (filepath.contains(".oup")) {
        m_model->setCheckFilePath(filepath);
    }
}
